﻿using Eto.Drawing;
using Eto.Forms;
using MultiLingualPanel.Resources;
using Rhino.UI;
using System;
using System.Collections.Generic;
using System.Globalization;
using System.Linq;
using System.Runtime.InteropServices;
using System.Text;
using System.Threading.Tasks;

namespace MultiLingualPanel
{
    class ContentPanel : Panel
    {
        DropDown languageDropDown;

        static ContentPanel()
        {
            MyStrings.Culture = new CultureInfo("en-US");
        }

        public ContentPanel()
        {
            var hello_button = new Button { Text = MyStrings.HelloButton };

            languageDropDown = new DropDown
            {
                Items = { 
                    new ListItem { Key = "en-US", Text = "English" }, 
                    new ListItem { Key = "fr-FR", Text = "French" },
                    new ListItem { Key = "es-ES", Text = "Spanish" }
                },
                SelectedKey = MyStrings.Culture?.Name ?? ""
            };

            languageDropDown.SelectedIndexChanged += languageDropDown_SelectedIndexChanged;


            var layout = new DynamicLayout { DefaultSpacing = new Size(5, 5), Padding = new Padding(10) };
            layout.AddSeparateRow(MyStrings.Language, languageDropDown, null);
            layout.AddSeparateRow(hello_button, null);
            layout.Add(null);
            Content = layout;
        }

        private void languageDropDown_SelectedIndexChanged(object sender, EventArgs e)
        {
            var culture = new CultureInfo(languageDropDown.SelectedKey);
            MyStrings.Culture = culture;
            FindParent<MultiLingualPanel>()?.CreateContent();
        }
    }

    [Guid("FA32E485-C6ED-42D7-AF6E-51AC93217ACD")]
    public class MultiLingualPanel : Panel, IPanel
    {
        public static Guid PanelId => typeof(MultiLingualPanel).GUID;

        public MultiLingualPanel()
        {
            CreateContent();
        }

        public void CreateContent()
        {
            Content = new ContentPanel();
        }

        public void PanelShown(uint documentSerialNumber, ShowPanelReason reason)
        {
        }

        public void PanelHidden(uint documentSerialNumber, ShowPanelReason reason)
        {
        }

        public void PanelClosing(uint documentSerialNumber, bool onCloseDocument)
        {
        }
    }
}
